package com.hfkj.service.goods.impl;

import com.hfkj.dao.BsOrderGoodsMapper;
import com.hfkj.entity.BsOrderGoods;
import com.hfkj.entity.BsOrderGoodsExample;
import com.hfkj.service.goods.BsOrderGoodsService;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service("bsOrderGoodsService")
public class BsOrderGoodsServiceImpl implements BsOrderGoodsService {

    @Resource
    private BsOrderGoodsMapper bsOrderGoodsMapper;

    @Override
    public void create(BsOrderGoods orderGoods) {
        bsOrderGoodsMapper.insert(orderGoods);
    }

    @Override
    public void update(BsOrderGoods orderGoods) {
        bsOrderGoodsMapper.updateByPrimaryKeySelective(orderGoods);
    }

    @Override
    public void delete(Long id, Boolean fullDelete) {
        if (fullDelete) {
            bsOrderGoodsMapper.deleteByPrimaryKey(id);
        } else {
            BsOrderGoods orderGoods = queryDetail(id);
            orderGoods.setStatus(0);
            orderGoods.setUpdateTime(new Date());
            update(orderGoods);
        }
    }

    @Override
    public BsOrderGoods findGoodsOrder(String orderNo) {
        BsOrderGoodsExample example = new BsOrderGoodsExample();
        example.createCriteria().andStatusNotEqualTo(0).andOrderNoEqualTo(orderNo);

        List<BsOrderGoods> list = bsOrderGoodsMapper.selectByExample(example);

        if (!list.isEmpty()) {
            return list.get(0);
        }

        return null;
    }

    @Override
    public BsOrderGoods queryDetail(Long id) {
        return bsOrderGoodsMapper.selectByPrimaryKey(id);
    }

    @Override
    public BsOrderGoods queryDetailByMap(Map<String, Object> map) {
        return null;
    }

    @Override
    public List<BsOrderGoods> getList(Map<String, Object> map) {
        BsOrderGoodsExample example = new BsOrderGoodsExample();
        BsOrderGoodsExample.Criteria criteria = example.createCriteria();

        if (MapUtils.getLong(map, "merId") != null) {
            criteria.andMerIdEqualTo(MapUtils.getLong(map, "merId"));
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "logisticsNo"))) {
            criteria.andLogisticsNoEqualTo(MapUtils.getString(map, "logisticsNo"));
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "orderNo"))) {
            criteria.andOrderNoEqualTo(MapUtils.getString(map, "orderNo"));
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "childOrderNo"))) {
            criteria.andChildOrderNoEqualTo(MapUtils.getString(map, "childOrderNo"));
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "userPhone"))) {
            criteria.andUserPhoneEqualTo(MapUtils.getString(map, "userPhone"));
        }
        if (MapUtils.getLong(map, "goodsType") != null) {
            criteria.andGoodsTypeIdEqualTo(MapUtils.getLong(map, "goodsType"));
        }
        if (MapUtils.getLong(map, "goodsBrand") != null) {
            criteria.andGoodsBrandIdEqualTo(MapUtils.getLong(map, "goodsBrand"));
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "goodsSpecsName"))) {
            criteria.andGoodsSpecsNameEqualTo(MapUtils.getString(map, "goodsSpecsName"));
        }

        if (StringUtils.isNotBlank(MapUtils.getString(map, "goodsName"))) {
            criteria.andGoodsNameLike("%"+MapUtils.getString(map, "goodsName")+"%");
        }

        if (StringUtils.isNotBlank(MapUtils.getString(map, "deliveryAddress"))) {
            criteria.andDeliveryAddressLike("%"+MapUtils.getString(map, "deliveryAddress")+"%");
        }
        if (MapUtils.getInteger(map, "payType") != null) {
            criteria.andPayTypeEqualTo(MapUtils.getInteger(map, "payType"));
        }
        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        } else {
            criteria.andStatusNotEqualTo(0);
        }

        return bsOrderGoodsMapper.selectByExample(example);
    }
}
